//LabPlot : OperationsListDialog.h

#ifndef OPERATIONSLISTDIALOG_H
#define OPERATIONSLISTDIALOG_H

#include "ListDialog.h"

class OperationsListDialog : public ListDialog
{
	Q_OBJECT
public:
	OperationsListDialog(MainWin *mw, const char *name);
public slots:
	void setOperation(int o) { 	type->setCurrentItem(o); }		//!< set type of operation
	void setType(int o) { setOperation(o); }
	void setFirst(int a) {set1ni->setValue(a); }		//!< set first set/column
	void setSecond(int b) {set2ni->setValue(b); }		//!< set second set/column
	int Apply() { return apply_clicked(); }
private:
	KIntNumInput *set1ni, *set2ni;
	KComboBox *type;
private slots:
	void saveSettings();
	int apply_clicked();
};

#endif // OPERATIONSLISTDIALOG_H
